<?php

class sspdc extends Director {

	function __construct() {
	
		Director::__construct(get_option('sspdc_api_key'), get_option('sspdc_api_path'), true);
		
		$sspdc_fmt = unserialize(get_option('sspdc_fmt'));
		
		# Regular size for display within posts
		$this->format->add(array('name' => 'post', 'width' => $sspdc_fmt['post_width'], 'height' => $sspdc_fmt['post_height'], 'crop' => $sspdc_fmt['post_crop'], 'quality' =>$sspdc_fmt['post_quality'], 'sharpening' => $sspdc_fmt['post_sharpening']));
		
		# Regular size for album preview image 
		$this->format->preview(array('width' => $sspdc_fmt['preview_width'], 'height' => $sspdc_fmt['preview_height'], 'crop' => $sspdc_fmt['preview_crop'], 'quality' =>$sspdc_fmt['preview_quality'], 'sharpening' => $sspdc_fmt['preview_sharpening']));
		
		# Size for  matrix thumbnails
		$this->format->add(array('name' => 'thumb', 'width' => $sspdc_fmt['matrix_width'], 'height' => $sspdc_fmt['matrix_height'], 'crop' => $sspdc_fmt['matrix_crop'], 'quality' => $sspdc_fmt['matrix_quality'], 'sharpening' => $sspdc_fmt['matrix_sharpening']));
		
		# Full size image for lightbox viewing
		$this->format->add(array('name' => 'fullsize', 'width' => $sspdc_fmt['fullsize_width'], 'height' => $sspdc_fmt['fullsize_height'], 'crop' => $sspdc_fmt['fullsize_crop'], 'quality' => $sspdc_fmt['fullsize_quality'], 'sharpening' => $sspdc_fmt['fullsize_sharpening']));
		
		# Size for photostrip thumbnails
		$this->format->add(array('name' => 'photostrip', 'width' => $sspdc_fmt['photostrip_width'], 'height' => $sspdc_fmt['photostrip_height'], 'crop' => $sspdc_fmt['photostrip_crop'], 'quality' => $sspdc_fmt['photostrip_quality'], 'sharpening' => $sspdc_fmt['photostrip_sharpening']));
		
		# Size for widget thumbnails
		$this->format->add(array('name' => 'widget', 'width' => $sspdc_fmt['widget_width'], 'height' => $sspdc_fmt['widget_height'], 'crop' => $sspdc_fmt['widget_crop'], 'quality' => $sspdc_fmt['widget_quality'], 'sharpening' => $sspdc_fmt['widget_sharpening']));
		
		# Size for video preview
		$this->format->add(array('name' => 'video_preview', 'width' => $sspdc_fmt['video_preview_width'], 'height' => $sspdc_fmt['video_preview_height'], 'crop' => $sspdc_fmt['video_preview_crop'], 'quality' => $sspdc_fmt['video_preview_quality'], 'sharpening' => $sspdc_fmt['video_preview_sharpening']));
		
		for ( $i = 1; $i <= 3; $i++ ) {
			if ( !empty($sspdc_fmt[$i]['name'])) {
				
				$this->format->add(array('name' => $sspdc_fmt[$i]['name'], 'width' => $sspdc_fmt[$i]['width'], 'height' => $sspdc_fmt[$i]['height'], 'crop' => $sspdc_fmt[$i]['crop'], 'quality' => $sspdc_fmt[$i]['quality'], 'sharpening' => $sspdc_fmt[$i]['sharpening']));
			}
		}
		
		if ( get_option('sspdc_cache') == '1' ) {
			$cache = $_SERVER["REQUEST_URI"];
			$this->cache->set('sspdc'. $cache);
		}
		
		$this->gallery = new sspdcGallery($this);
		$this->album = new sspdcAlbum($this);
		$this->content = new sspdcContent($this);
	}
}

class sspdcGallery extends DirectorGallery {
	
	public function html( $gallery_id ) {
		
		$gallery = $this->get( $gallery_id );
		
		foreach ( $gallery->albums->album AS $album ) {	
			
			$a = new sspdc;
			
			$html .= $a->album->html($album->id, 'preview', 'true', 'lightbox');	
		}
		
		
		
		return $html;
	}

}

class sspdcAlbum extends DirectorAlbum {

	public function html( $album_id, $style = 'matrix', $description = 'false', $link = 'lightbox' ) {
		/* 
		Create html for an album.
		Either matrix view or album preview image as entry point 
		
		[sspdc album=(album_id) style=(preview|matrix) description=(true|false) link=(none|lightbox|director|url:)]
		*/	
		
		/* get album data */
		
		$album = $this->get( $album_id );
		$images = $album->contents[0];
		
		$html = '';	
		
		if ( $style == 'preview') {
			
			/* 	
				Create preview as entry point of the given SSP Director album with attached lightbox view 
				
				CSS:
					.sspdc_album_preview: 	container class 
					.sspdc_album_text:		container class for name and desc.
			*/
			
			$html = '';
					
			$url = explode( ':', $link, 2);
			
			if ( $url[0] == 'url') {
				$html .= '<div class="sspdc_album_preview">';
				$html .= '<a href="'. $url[1] . '">';
				$html .= '<img src="' .  $album->preview->url . '"  alt="' . $image->title . '" /></a>';
			}
			
			elseif ( $link == 'none' ) {
		
				$html .= '<div class="sspdc_album_preview">';
				$html .= '<img src="' .  $album->preview->url . '"  alt="' . $image->title . '" />';
			}
			
			elseif ( empty( $link ) || $link == 'lightbox' ) {
			
				foreach( $images as $image ) {
							
					if ( $html == '' ) {
						$html .= '<div class="sspdc_album_preview">';
						
						$html .= '<a href="'. $image->fullsize->url . '" rel="lightbox[album'.$album_id.']" title="'.  $image->title . '. ' . $image->caption .'"><img src="' .  $album->preview->url . '"  alt="' . $image->title . '" /></a>';
						
					}
					
					else {
					
						$html .= '<a href="'. $image->fullsize->url . '" rel="lightbox[album'.$album_id.']" title="'.  $image->title . '. ' . $image->caption . '" alt="' . $image->title . '" /> </a>';
					}
				}
			}
			
			if ( $description == 'true' && $url[0] == 'url') {
				
				$html .= '<div class="sspdc_album_text"><div class="sspdc_album_name"><h3><a href="' .$url[1]. '">'. $album->name . '</a></h3></div><div class="sspdc_album_description"><p>'. $album->description . '</p></div></div>';
			}
			
			elseif ( $description == 'true' ) {
				
				$html .= '<div class="sspdc_album_text"><div class="sspdc_album_name"><h3>'. $album->name . '</h3></div><div class="sspdc_album_description"><p>'. $album->description . '</p></div></div>';
			}
			
			$html .= '</div><br clear="left" />';
		}
		
		elseif ( $style == "matrix" ) {
			
			/* 	
				Create thumbnail matrix as entry point of the given SSP Director album with attached lightbox view 
				
				CSS:
					.sspdc_matrix: 			container class for all thumbnails
					.sspdc_thumbnail:		thumbnail class
			*/
			
			$html = '<div class="sspdc_album_matrix">';
			
			if ( $description == 'true' ) {
			
				$html .= '<div class="sspdc_album_text"><div class="sspdc_album_name"><h4>'. $album->name . '</h4></div><div class="sspdc_album_description"><p>'. $album->description . '</p></div></div>';
			}
				
			foreach( $images as $image ) {
				
				if ( $image->title == ""  )  {
			
					$title = "";
				}
			
				else {
			
					$title =  utf8_decode( $image->title );
				}
			
				if ( $image->caption == "" )  {
			
				}
				
				else {
				
					if ( $title !== "" ) {
				
						$title .= ". ";
					}
				
					$title .= utf8_decode( $image->caption)  . ".";
				}
				
				if ( $link == 'director' ) {
					$link_url = $content->link;
				
					if ( $content->target == FALSE) {
						$link_target = '_blank';
					}
					
					else {
						$link_target = '_self';
					}
					
					$html .= '<div class="sspdc_thumbnail"><a href="'. $link_url . '" title="'.  $title . '"><img src="' . $image->thumb->url . '"  alt="'  . $image->title . '"  target="'. $link_target . '" /></a></div>';
					
				}
				
				else {
				
					$html .= '<div class="sspdc_thumbnail"><a href="'. $image->fullsize->url . '" rel="lightbox[matrix]" title="'.  $title . '"><img src="' . $image->thumb->url . '"  alt="'  . $image->title . '" /></a></div>';
				}
			}	
			
			$html .= '</div>';
		}
		
	return $html;
	
	}
}

class sspdcContent extends DirectorContent {

	public function html( $content_id, $link = 'lightbox', $format = 'post', $mediaplayer = '' ) {
		
		$content = $this->get( $content_id );
		
		//echo print_r ( $content );
		
		$director = new sspdc;
		
		if ( $director->utils->is_image( $content->src ) ) {
			
			if ( $content->title == ""  )  {
			
				$title = "";
			}
			
			else {
			
				$title =  utf8_decode( $content->title );
			}
			
			if ( $content->caption == "" )  {
			
				}
				
			else {
				
				if ( $title !== "" ) {
				
					$title .= ". ";
				}
				
				$title .=  $content->caption . ".";
			}
			
			$html = '<div class="sspdc_image">';
			$link_target = '_self';
			$url = explode( ':', $link, 2);
			
			if ( $url[0] == 'url' ) {
				$link_url = $url[1];
			}
			
			elseif ( $link == 'post' ) {
				
				$link_url = get_bloginfo('siteurl') . '/?p=' . get_the_ID();
			}
			
			elseif ( $link == 'director' ) {
				$link_url = $content->link;
				
				if ( $content->target == FALSE ) {
					$link_target = '_blank';
				}
			}
			
			elseif ( empty( $link ) || $link == 'lightbox' ) {
				$link_url = $content->fullsize->url . '" rel="lightbox[image]"	';
			}
			
			
			
			if ( $format == 'post' || empty($format)  ) {
			
				$content_url = $content->post->url;
			}
			
			else {

				$content_url = $content->$format->url;
				
			}
			
			$html .= '<a href="' . $link_url . '" target="' . $link_target . '" title="'.  $title . '"><img src="' .  $content_url . '"  alt="' . $content->title . '" /> </a>';
		
			$html .= '</div>';
		}
		
		else {
		
			
			$html = '<span id="video-'.get_the_ID().'">Sorry. FLV player did not load.</span>';
			
			$sspdc_fmt = unserialize(get_option('sspdc_fmt'));			

			if (!empty( $mediaplayer ) ){
				$options = explode( '&', $mediaplayer);
				
				foreach ($options as $option ) {
					
					$vars = explode ( '=', $option );
					
					$mediaplayer_vars[$vars[0]] = $vars[1]; 
				}
				
				$addVariable = '';
				foreach ( $mediaplayer_vars as $key => $value )	{
				    
				    $addVariable .= 'flashvars.'.$key.' ="'.$value.'";';
				}
				
			}
			
			
			$html .= 	'<script type="text/javascript">';
			$html .=	'var flashvars = {};';
			$html .=	'flashvars.id 			= "n'.get_the_ID().'";';
			$html .=	'flashvars.controlbar 	= "over";';
			$html .=	'flashvars.image 		= "'.$content->video_preview->url.'";';
			$html .=	'flashvars.file			= "'.$content->original->url.'";';
			$html .=	$addVariable;
			
			$html .=	'var params = {};';
			$html .=	'params.allowfullscreen = "true";';
			$html .=	'params.allowscriptaccess = "always";';
			
			$html .=	'var attributes = {};';
			$html .=	'attributes.id = "video-'.get_the_ID().'";';
			
			$html .= 'swfobject.embedSWF("'. get_settings("siteurl").'/wp-content/plugins/'.dirname(plugin_basename(__FILE__)).'/js/mediaplayer/player.swf", "video-'.get_the_ID().'", "'.$sspdc_fmt["video_width"].'", "'.$sspdc_fmt["video_height"].'", "9.0.0","'. get_settings("siteurl").'/wp-content/plugins/'.dirname(plugin_basename(__FILE__)).'/js/mediaplayer/expressinstall.swf", flashvars, params, attributes);';
			$html .= 	'</script>';
		}
		
		return $html;		
	}
}
?>